@@ -225,12 +225,6 @@
 /* Define to `unsigned int' if <sys/types.h> or <signal.h> doesn't define */
 #undef sigset_t
 
-/* Define to `unsigned short' if <sys/types> or <stdlib.h> doesn't define */
-#undef ushort
-
-/* Define to `unsigned long' if <sys/types> or <stdlib.h> doesn't define */
-#undef ulong
-
 /*
  * Define to 1 if your vi has ATT bug, such that it returns
  * non-zero exit codes on `pseudo-errors'.
