@@ -42,6 +42,7 @@ void cpydgst (int, int, char *, char *);
 void discard (FILE *);
 void done (int);
 int fdcompare (int, int);
+int folder_delmsgs (struct msgs *, int);
 int gans (char *, struct swit *);
 char **getans (char *, struct swit *);
 int getanswer (char *);
@@ -53,31 +54,22 @@ int m_delete (char *);
 char *m_draft (char *, char *, int, int *);
 void m_eomsbr (int (*)());
 char *m_find(char *);
-void m_fmsg (struct msgs *);
 void m_foil (char *);
+void m_freefolder (struct msgs *);
 void m_getdefs(void);
 int m_getfld (int, unsigned char *, unsigned char *, int, FILE *);
 char *m_getfolder(void);
 int m_gmprot (void);
-struct msgs *m_gmsg (char *);
 char *m_maildir (char *);
 char *m_mailpath (char *);
 char *m_name (int);
+struct msgs *m_packfolder (struct msgs *, int);
 int m_putenv (char *, char *);
 void m_readefs (struct node **, FILE *, char *, int);
+struct msgs *m_readfolder (char *);
 struct msgs *m_remsg ();
 void m_replace (char *, char *);
 char *m_scratch (char *, char *);
-char *m_seq (struct msgs *, char *);
-int m_seqadd (struct msgs *, char *, int, int);
-char *m_seqbits (struct msgs *);
-int m_seqdel (struct msgs *, char *, int);
-int m_seqflag (struct msgs *, char *);
-int m_seqnew (struct msgs *, char *, int);
-void m_setcur (struct msgs *, int);
-void m_setseq (struct msgs *);
-void m_setvis (struct msgs *, int);
-void m_sync (struct msgs *);
 char *m_tmpfil (char *);
 void m_unknown(FILE *);
 void m_update(void);
@@ -95,6 +87,19 @@ char *pwd (void);
 char *r1bindex(char *, int);
 int refile (char **, char *);
 int remdir (char *);
+int seq_addmsg (struct msgs *, char *, int, int, int);
+int seq_addsel (struct msgs *, char *, int, int);
+char *seq_bits (struct msgs *);
+int seq_delmsg (struct msgs *, char *, int);
+int seq_delsel (struct msgs *, char *, int, int);
+int seq_getnum (struct msgs *, char *);
+char *seq_list (struct msgs *, char *);
+int seq_nameok (char *);
+void seq_read (struct msgs *);
+void seq_save (struct msgs *);
+void seq_setcur (struct msgs *, int);
+void seq_setprev (struct msgs *);
+void seq_setunseen (struct msgs *, int);
 int showfile (char **, char *);
 int smatch(char *, struct swit *);
 char *sprintb (char *, unsigned, char *);
