@@ -492,7 +492,7 @@ do_func(char *sp)
 	break;
 
     case TF_NOW:
-	LV(t->f_type, time((long *) 0));
+	LV(t->f_type, time((time_t *) 0));
 	break;
 
     case TF_EXPR_SV:
