@@ -169,7 +169,7 @@ mbx_read (FILE *fp, long pos, struct drop **drops, int noisy)
     ld1 = (long) strlen (mmdlm1);
     ld2 = (long) strlen (mmdlm2);
 
-    fseek (fp, pos, 0);
+    fseek (fp, pos, SEEK_SET);
     for (ep = (dp = pp) + len - 1; fgets (buffer, sizeof buffer, fp);) {
 	size = 0;
 	if (strcmp (buffer, mmdlm1) == 0)
@@ -239,7 +239,7 @@ mbx_write(char *mailbox, int md, FILE *fp, int id, long last,
     start = lseek (md, (off_t) 0, SEEK_CUR);
     size = 0;
 
-    fseek (fp, pos, 0);
+    fseek (fp, pos, SEEK_SET);
     while (fgets (buffer, sizeof buffer, fp) && (pos < stop)) {
 	i = strlen (buffer);
 	for (j = 0; (j = stringdex (mmdlm1, buffer)) >= 0; buffer[j]++)
@@ -356,7 +356,7 @@ mbx_copy (char *mailbox, int mbx_style, int md, int fd,
 		    ep = tmpbuffer + 13;
 		    if (!(fp = strchr(ep + 1, ' ')))
 			fp = strchr(ep + 1, '\n');
-		    tp = dctime(dtwstime());
+		    tp = dctime(dlocaltimenow());
 		    sprintf (buffer, "From %.*s  %s", fp - ep, ep, tp);
 		}
 
@@ -409,7 +409,7 @@ mbx_size (int md, off_t start, off_t stop)
 	return NOTOK;
     }
 
-    fseek (fp, start, 0);
+    fseek (fp, start, SEEK_SET);
     for (i = 0, pos = stop - start; pos-- > 0; i++)
 	if (fgetc (fp) == '\n')
 	    i++;
@@ -457,7 +457,7 @@ map_read (char *file, long pos, struct drop **drops, int noisy)
     struct drop d;
     register struct drop *mp, *dp;
 
-    if ((md = open (cp = map_name (file), 0)) == NOTOK
+    if ((md = open (cp = map_name (file), O_RDONLY)) == NOTOK
 	    || map_chk (cp, md, mp = &d, pos, noisy)) {
 	if (md != NOTOK)
 	    close (md);
