@@ -1467,7 +1467,7 @@ doface (struct mcomp *c1)
     static int inited = OK;
     static int addrlen;
     static struct in_addr addr;
-    static ushort portno;
+    static unsigned short portno;
 
     if (inited == OK) {
 	char *cp;
@@ -1484,7 +1484,7 @@ bad_faceproc: ;
 	    goto bad_faceproc;
 	memcpy((char *) &addr, hp->h_addr, addrlen = hp->h_length);
 
-	portno = htons ((ushort) atoi (ap[1]));
+	portno = htons ((unsigned short) atoi (ap[1]));
 	free (cp);
 
 	inited = DONE;
