@@ -20,7 +20,11 @@
 #ifndef	TTYD
 # include <utmp.h>
 # ifndef UTMP_FILE
-#  define UTMP_FILE "/etc/utmp"
+#  ifdef _PATH_UTMP
+#   define UTMP_FILE _PATH_UTMP
+#  else
+#   define UTMP_FILE "/etc/utmp"
+#  endif
 # endif
 #endif
 
