@@ -323,16 +323,17 @@ remove_files (int filep, char **files)
 
 /*
  * Link (or copy) the message into each of
- * the destiniation folders.
+ * the destination folders.
  */
 
 static int
 m_file (char *msgfile, struct st_fold *folders, int nfolders, int preserve)
 {
+    int msgnum;
     struct st_fold *fp, *ep;
 
     for (fp = folders, ep = folders + nfolders; fp < ep; fp++) {
-	if (addmsg (&fp->f_mp, msgfile, preserve))
+	if ((msgnum = addmsg (&fp->f_mp, msgfile, preserve)) == -1)
 	    return 1;
     }
     return 0;
@@ -340,7 +341,8 @@ m_file (char *msgfile, struct st_fold *folders, int nfolders, int preserve)
 
 
 /*
- * Link message into a folder
+ * Link message into a folder.  Return the new number
+ * of the message.  If an error occurs, return -1.
  */
 
 static int
@@ -416,10 +418,10 @@ addmsg (struct msgs **mpp, char *msgfile, int preserve)
 	if (linkerr == EEXIST) {
 	    if (stat (msgfile, &st2) == OK && stat (newmsg, &st1) == OK
 		&& st2.st_ino == st1.st_ino) {
-		return 0;
+		return msgnum;
 	    } else {
 		advise (NULL, "message %s already exists", newmsg);
-		return 1;
+		return -1;
 	    }
 	}
 
@@ -432,22 +434,22 @@ addmsg (struct msgs **mpp, char *msgfile, int preserve)
 	if (linkerr == EXDEV) {
 	    if (stat (newmsg, &st1) == OK) {
 		advise (NULL, "message %s:%s already exists", newmsg);
-		return 1;
+		return -1;
 	    } else {
 		if ((in = open (msgfile, O_RDONLY)) == NOTOK) {
 		    advise (msgfile, "unable to open message %s");
-		    return 1;
+		    return -1;
 		}
 		fstat (in, &st1);
 		if ((out = creat (newmsg, (int) st1.st_mode & 0777)) == NOTOK) {
 		    advise (newmsg, "unable to create");
 		    close (in);
-		    return 1;
+		    return -1;
 		}
 		cpydata (in, out, msgfile, newmsg);
 		close (in);
 		close (out);
-		return 0;
+		return msgnum;
 	    }
 	}
 
@@ -456,8 +458,8 @@ addmsg (struct msgs **mpp, char *msgfile, int preserve)
 	 * so just return error.
 	 */
 	advise (newmsg, "error linking %s to", msgfile);
-	return 1;
+	return -1;
     }
 
-    return 0;
+    return msgnum;
 }
