@@ -29,10 +29,19 @@
 #include <pwd.h>
 #include <signal.h>
 #include <sys/ioctl.h>
-#include <utmp.h>
 #include <ndbm.h>
 #include <fcntl.h>
 
+#include <utmp.h>
+
+#ifndef UTMP_FILE
+# ifdef _PATH_UTMP
+#  define UTMP_FILE _PATH_UTMP
+# else
+#  define UTMP_FILE "/etc/utmp"
+# endif
+#endif
+
 static struct swit switches[] = {
 #define	ADDRSW         0
     { "addr address", 0 },
@@ -792,12 +801,12 @@ static int
 logged_in (void)
 {
     struct utmp ut;
-    register FILE *uf;
+    FILE *uf;
 
     if (utmped)
 	return utmped;
 
-    if ((uf = fopen ("/etc/utmp", "r")) == NULL)
+    if ((uf = fopen (UTMP_FILE, "r")) == NULL)
 	return NOTOK;
 
     while (fread ((char *) &ut, sizeof(ut), 1, uf) == 1)
